@@ -47,7 +47,8 @@ def record(tag, template, using=None, **kwargs):
        kwargs:
            a mapping of object or data to interpolate in the format string
     '''
-    with transaction.commit_on_success(using=using):
+    try:
+        sid = transaction.savepoint()
         template = unicode(template)
         tag = get_tag(tag, using=using)
         template = get_template(template, using=using)
@@ -77,7 +78,10 @@ def record(tag, template, using=None, **kwargs):
                 journal.objectdata_set.create(tag=tag, content_object=value)
             else:
                 journal.stringdata_set.create(tag=tag, content=unicode(value))
+        transaction.savepoint_commit(sid)
         return journal
+    except:
+        transaction.savepoint_rollback(sid)
 
 def error_record(tag, tpl, **kwargs):
     '''Records error events.
